@@ -443,7 +443,8 @@ public class RelationExtractor
 		// QuotesParensSentenceDetector ds = QuotesParensSentenceDetector.create();
 
 		ParseView ceregoView = new ParseView();
-		OpenCogScheme opencog = new OpenCogScheme();
+		OpenCogScheme opencog = null;
+		if (commandMap.get("-o") != null) opencog = new OpenCogScheme();
 
 		Frame frame = null;
 		if (commandMap.get("-f") != null) frame = new Frame();
@@ -655,6 +656,10 @@ public class RelationExtractor
 			System.out.println(opencog.printDocument(re.doco));
 		}
 		System.out.println("; Bye.");
+		if (commandMap.get("-o") != null)
+		{
+			System.out.println(".\nexit");
+		}
 	}
 }
 
